<?php

namespace Harmony\Clientdetail\Policies;

use Litepie\User\Contracts\UserPolicy;
use Harmony\Clientdetail\Models\ClientDetail;

class ClientDetailPolicy
{

    /**
     * Determine if the given user can view the client_detail.
     *
     * @param UserPolicy $user
     * @param ClientDetail $client_detail
     *
     * @return bool
     */
    public function view(UserPolicy $user, ClientDetail $client_detail)
    {
        if ($user->canDo('clientdetail.client_detail.view') && $user->isAdmin()) {
            return true;
        }

        return $client_detail->user_id == user_id() && $client_detail->user_type == user_type();
    }

    /**
     * Determine if the given user can create a client_detail.
     *
     * @param UserPolicy $user
     * @param ClientDetail $client_detail
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('clientdetail.client_detail.create');
    }

    /**
     * Determine if the given user can update the given client_detail.
     *
     * @param UserPolicy $user
     * @param ClientDetail $client_detail
     *
     * @return bool
     */
    public function update(UserPolicy $user, ClientDetail $client_detail)
    {
        if ($user->canDo('clientdetail.client_detail.edit') && $user->isAdmin()) {
            return true;
        }

        return $client_detail->user_id == user_id() && $client_detail->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given client_detail.
     *
     * @param UserPolicy $user
     * @param ClientDetail $client_detail
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ClientDetail $client_detail)
    {
        return $client_detail->user_id == user_id() && $client_detail->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given client_detail.
     *
     * @param UserPolicy $user
     * @param ClientDetail $client_detail
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ClientDetail $client_detail)
    {
        if ($user->canDo('clientdetail.client_detail.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given client_detail.
     *
     * @param UserPolicy $user
     * @param ClientDetail $client_detail
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ClientDetail $client_detail)
    {
        if ($user->canDo('clientdetail.client_detail.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
