<?php

namespace Harmony\Clientdetail\Providers;

use Illuminate\Support\ServiceProvider;

class ClientdetailServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'clientdetail');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'clientdetail');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerClientdetail();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerClientdetail()
    {
        $this->app->bind('clientdetail', function($app) {
            return new Clientdetail($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Clientdetail', 'Lavalite\Clientdetail\Facades\Clientdetail');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('harmony.clientdetail', function ($app) {
            return $this->app->make('Harmony\Clientdetail\Clientdetail');
        });

                // Bind ClientDetail to repository
        $this->app->bind(
            'Harmony\Clientdetail\Interfaces\ClientDetailRepositoryInterface',
            \Harmony\Clientdetail\Repositories\Eloquent\ClientDetailRepository::class
        );

        $this->app->register(\Harmony\Clientdetail\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Harmony\Clientdetail\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and clientdetail's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/clientdetail.php', 'clientdetail'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeClientdetail::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['harmony.clientdetail'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('harmony/clientdetail.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/clientdetail')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/clientdetail')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
